import setuptools
setuptools.setup(
    name='Adil Boudida.AI',
    version='0.1',
    author='Adil Boudida',
    description='Professional in Python Framwork for Artificial Intelligence',
    package=setuptools.find_packages(),
    classifiers=[
    "Programming Language :: Python :: 3",
    "Operating System :: OS Independent",
    "License :: OSI Approved :: MIT License"
    ]
)








